@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed.c,v 1.26 2003/12/05 23:11:06 chpe Exp $
+ *  $Id: ephy-embed.c,v 1.30.6.5 2004/07/10 18:45:22 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -28,7 +28,29 @@
 #include "mozilla-embed-single.h"
 #include "mozilla-embed.h"
 
-static void ephy_embed_base_init (gpointer base_class);
+static void ephy_embed_base_init (gpointer g_class);
+
+GType
+ephy_embed_chrome_get_type (void)
+{
+	static GType etype = 0;
+
+	if (etype == 0)
+	{
+		static const GFlagsValue values[] =
+		{
+		{ EPHY_EMBED_CHROME_MENUBAR, "EPHY_EMBED_CHROME_MENUBAR", "menubar" },
+		{ EPHY_EMBED_CHROME_TOOLBAR, "EPHY_EMBED_CHROME_TOOLBAR", "toolbar" },
+		{ EPHY_EMBED_CHROME_STATUSBAR, "EPHY_EMBED_CHROME_STATUSBAR", "statusbar" },
+		{ EPHY_EMBED_CHROME_BOOKMARKSBAR, "EPHY_EMBED_CHROME_BOOKMARKSBAR", "bookmarksbar" },
+		{ 0, NULL, NULL }
+		};
+
+		etype = g_flags_register_static ("EphyEmbedChrome", values);
+	}
+
+	return etype;
+}
 
 GType
 ephy_embed_get_type (void)
@@ -39,7 +61,7 @@ ephy_embed_get_type (void)
 	{
 		static const GTypeInfo our_info =
 		{
-			sizeof (EphyEmbedClass),
+			sizeof (EphyEmbedIface),
 			ephy_embed_base_init,
 			NULL,
 		};
@@ -63,7 +85,7 @@ ephy_embed_base_init (gpointer g_class)
 		g_signal_new ("ge_new_window",
 			      EPHY_TYPE_EMBED,
 			      G_SIGNAL_RUN_FIRST,
-			      G_STRUCT_OFFSET (EphyEmbedClass, new_window),
+			      G_STRUCT_OFFSET (EphyEmbedIface, new_window),
 			      NULL, NULL,
 			      ephy_marshal_VOID__POINTER_INT,
 			      G_TYPE_NONE,
@@ -73,7 +95,7 @@ ephy_embed_base_init (gpointer g_class)
 		g_signal_new ("ge_context_menu",
 			      EPHY_TYPE_EMBED,
 			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (EphyEmbedClass, context_menu),
+			      G_STRUCT_OFFSET (EphyEmbedIface, context_menu),
 			      g_signal_accumulator_true_handled, NULL,
 			      ephy_marshal_BOOLEAN__OBJECT,
 			      G_TYPE_BOOLEAN,
@@ -82,7 +104,7 @@ ephy_embed_base_init (gpointer g_class)
 		g_signal_new ("ge_favicon",
 			      EPHY_TYPE_EMBED,
 			      G_SIGNAL_RUN_FIRST,
-			      G_STRUCT_OFFSET (EphyEmbedClass, favicon),
+			      G_STRUCT_OFFSET (EphyEmbedIface, favicon),
 			      NULL, NULL,
 			      g_cclosure_marshal_VOID__STRING,
 			      G_TYPE_NONE,
@@ -91,7 +113,7 @@ ephy_embed_base_init (gpointer g_class)
 		g_signal_new ("ge_location",
 			      EPHY_TYPE_EMBED,
 			      G_SIGNAL_RUN_FIRST,
-			      G_STRUCT_OFFSET (EphyEmbedClass, location),
+			      G_STRUCT_OFFSET (EphyEmbedIface, location),
 			      NULL, NULL,
 			      g_cclosure_marshal_VOID__STRING,
 			      G_TYPE_NONE,
@@ -100,7 +122,7 @@ ephy_embed_base_init (gpointer g_class)
 		g_signal_new ("ge_net_state",
 			      EPHY_TYPE_EMBED,
 			      G_SIGNAL_RUN_FIRST,
-			      G_STRUCT_OFFSET (EphyEmbedClass, net_state),
+			      G_STRUCT_OFFSET (EphyEmbedIface, net_state),
 			      NULL, NULL,
 			      ephy_marshal_VOID__STRING_INT,
 			      G_TYPE_NONE,
@@ -110,7 +132,7 @@ ephy_embed_base_init (gpointer g_class)
 		g_signal_new ("ge_dom_mouse_click",
 			      EPHY_TYPE_EMBED,
 			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (EphyEmbedClass, dom_mouse_click),
+			      G_STRUCT_OFFSET (EphyEmbedIface, dom_mouse_click),
 			      g_signal_accumulator_true_handled, NULL,
 			      ephy_marshal_BOOLEAN__OBJECT,
 			      G_TYPE_BOOLEAN,
@@ -119,16 +141,24 @@ ephy_embed_base_init (gpointer g_class)
 		g_signal_new ("ge_dom_mouse_down",
 			      EPHY_TYPE_EMBED,
 			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (EphyEmbedClass, dom_mouse_down),
+			      G_STRUCT_OFFSET (EphyEmbedIface, dom_mouse_down),
 			      g_signal_accumulator_true_handled, NULL,
 			      ephy_marshal_BOOLEAN__OBJECT,
 			      G_TYPE_BOOLEAN,
 			      1,
 			      G_TYPE_POINTER);
+		g_signal_new ("ge_popup_blocked",
+			      EPHY_TYPE_EMBED,
+			      G_SIGNAL_RUN_FIRST,
+			      G_STRUCT_OFFSET (EphyEmbedIface, popup_blocked),
+			      NULL, NULL,
+			      g_cclosure_marshal_VOID__VOID,
+			      G_TYPE_NONE,
+			      0);
 		g_signal_new ("ge_security_change",
 			      EPHY_TYPE_EMBED,
 			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (EphyEmbedClass, security_change),
+			      G_STRUCT_OFFSET (EphyEmbedIface, security_change),
 			      NULL, NULL,
 			      g_cclosure_marshal_VOID__INT,
 			      G_TYPE_NONE,
@@ -137,12 +167,13 @@ ephy_embed_base_init (gpointer g_class)
 		g_signal_new ("ge_zoom_change",
 			      EPHY_TYPE_EMBED,
 			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (EphyEmbedClass, zoom_change),
+			      G_STRUCT_OFFSET (EphyEmbedIface, zoom_change),
 			      NULL, NULL,
 			      g_cclosure_marshal_VOID__FLOAT,
 			      G_TYPE_NONE,
 			      1,
 			      G_TYPE_FLOAT);
+
 		initialized = TRUE;
 	}
 }
@@ -151,102 +182,102 @@ void
 ephy_embed_load_url (EphyEmbed *embed,
 		     const char *url)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	klass->load_url (embed, url);
+	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
+	iface->load_url (embed, url);
 }
 
 void
 ephy_embed_stop_load (EphyEmbed *embed)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	klass->stop_load (embed);
+	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
+	iface->stop_load (embed);
 }
 
 gboolean
 ephy_embed_can_go_back (EphyEmbed *embed)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	return klass->can_go_back (embed);
+	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
+	return iface->can_go_back (embed);
 }
 
 gboolean
 ephy_embed_can_go_forward (EphyEmbed *embed)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	return klass->can_go_forward (embed);
+	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
+	return iface->can_go_forward (embed);
 }
 
 gboolean
 ephy_embed_can_go_up (EphyEmbed *embed)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	return klass->can_go_up (embed);
+	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
+	return iface->can_go_up (embed);
 }
 
 GSList *
 ephy_embed_get_go_up_list (EphyEmbed *embed)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	return klass->get_go_up_list (embed);
+	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
+	return iface->get_go_up_list (embed);
 }
 
 void
 ephy_embed_go_back (EphyEmbed *embed)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	klass->go_back (embed);
+	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
+	iface->go_back (embed);
 }
 
 void
 ephy_embed_go_forward (EphyEmbed *embed)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	klass->go_forward (embed);
+	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
+	iface->go_forward (embed);
 }
 
 void
 ephy_embed_go_up (EphyEmbed *embed)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	klass->go_up (embed);
+	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
+	iface->go_up (embed);
 }
 
 
 char *
 ephy_embed_get_title (EphyEmbed *embed)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	return klass->get_title (embed);
+	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
+	return iface->get_title (embed);
 }
 
 char *
 ephy_embed_get_location (EphyEmbed *embed,
 			 gboolean toplevel)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	return klass->get_location (embed, toplevel);
+	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
+	return iface->get_location (embed, toplevel);
 }
 
 char *
 ephy_embed_get_link_message (EphyEmbed *embed)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	return klass->get_link_message (embed);
+	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
+	return iface->get_link_message (embed);
 }
 
 char *
 ephy_embed_get_js_status (EphyEmbed *embed)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	return klass->get_js_status (embed);
+	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
+	return iface->get_js_status (embed);
 }
 
 void
 ephy_embed_reload (EphyEmbed *embed,
 		   EmbedReloadFlags flags)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	klass->reload (embed, flags);
+	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
+	iface->reload (embed, flags);
 }
 
 void
@@ -254,22 +285,22 @@ ephy_embed_zoom_set (EphyEmbed *embed,
 		     float zoom,
 		     gboolean reflow)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	klass->zoom_set (embed, zoom, reflow);
+	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
+	iface->zoom_set (embed, zoom, reflow);
 }
 
 float
 ephy_embed_zoom_get (EphyEmbed *embed)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	return klass->zoom_get (embed);
+	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
+	return iface->zoom_get (embed);
 }
 
 int
 ephy_embed_shistory_n_items  (EphyEmbed *embed)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	return klass->shistory_n_items (embed);
+	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
+	return iface->shistory_n_items (embed);
 }
 
 void
@@ -279,23 +310,23 @@ ephy_embed_shistory_get_nth (EphyEmbed *embed,
 			     char **url,
 			     char **title)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	klass->shistory_get_nth (embed, nth, is_relative, url, title);
+	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
+	iface->shistory_get_nth (embed, nth, is_relative, url, title);
 }
 
 int
 ephy_embed_shistory_get_pos (EphyEmbed *embed)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	return klass->shistory_get_pos (embed);
+	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
+	return iface->shistory_get_pos (embed);
 }
 
 void
 ephy_embed_shistory_go_nth (EphyEmbed *embed,
 			    int nth)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	klass->shistory_go_nth (embed, nth);
+	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
+	iface->shistory_go_nth (embed, nth);
 }
 
 void
@@ -303,8 +334,8 @@ ephy_embed_get_security_level (EphyEmbed *embed,
 			       EmbedSecurityLevel *level,
 			       char **description)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	klass->get_security_level (embed, level, description);
+	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
+	iface->get_security_level (embed, level, description);
 }
 
 void
@@ -313,60 +344,60 @@ ephy_embed_find_set_properties  (EphyEmbed *embed,
 				 gboolean case_sensitive,
 				 gboolean match_word)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	klass->find_set_properties (embed, search_string, case_sensitive, match_word);
+	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
+	iface->find_set_properties (embed, search_string, case_sensitive, match_word);
 }
 
 gboolean
 ephy_embed_find_next (EphyEmbed *embed,
 		      gboolean backwards)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	return klass->find_next (embed, backwards);
+	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
+	return iface->find_next (embed, backwards);
 }
 
 void
 ephy_embed_activate (EphyEmbed *embed)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	klass->activate (embed);
+	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
+	iface->activate (embed);
 }
 
 void
 ephy_embed_set_encoding (EphyEmbed *embed,
 			 const char *encoding)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	klass->set_encoding (embed, encoding);
+	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
+	iface->set_encoding (embed, encoding);
 }
 
 EphyEncodingInfo *
 ephy_embed_get_encoding_info (EphyEmbed *embed)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	return klass->get_encoding_info (embed);
+	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
+	return iface->get_encoding_info (embed);
 }
 
 void
-ephy_embed_print (EphyEmbed *embed,
-		  EmbedPrintInfo *info)
+ephy_embed_print (EphyEmbed *embed)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	klass->print (embed, info);
+	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
+	iface->print (embed);
 }
 
 void
-ephy_embed_print_preview_close (EphyEmbed *embed)
+ephy_embed_set_print_preview_mode (EphyEmbed *embed,
+				   gboolean preview_mode)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	klass->print_preview_close (embed);
+	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
+	iface->set_print_preview_mode (embed, preview_mode);
 }
 
 int
 ephy_embed_print_preview_n_pages (EphyEmbed *embed)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	return klass->print_preview_n_pages (embed);
+	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
+	return iface->print_preview_n_pages (embed);
 }
 
 void
@@ -374,6 +405,13 @@ ephy_embed_print_preview_navigate (EphyEmbed *embed,
 				   EmbedPrintPreviewNavType type,
 				   int page)
 {
-	EphyEmbedClass *klass = EPHY_EMBED_GET_CLASS (embed);
-	return klass->print_preview_navigate (embed, type, page);
+	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
+	iface->print_preview_navigate (embed, type, page);
+}
+
+gboolean
+ephy_embed_has_modified_forms (EphyEmbed *embed)
+{
+	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
+	return iface->has_modified_forms (embed);
 }
