@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyBrowser.h,v 1.9 2004/01/04 12:52:05 chpe Exp $
+ *  $Id: EphyBrowser.h,v 1.10.4.3 2004/07/31 15:37:54 chpe Exp $
  */
 
 #ifndef EPHY_BROWSER_H
@@ -88,9 +88,8 @@ public:
 	nsresult SetZoom (float aTextZoom, PRBool reflow);
 	nsresult GetZoom (float *aTextZoom);
 
-	nsresult Print (nsIPrintSettings *options, PRBool preview);
-	nsresult GetPrintSettings (nsIPrintSettings * *options);
-	nsresult PrintPreviewClose (void);
+	nsresult Print ();
+	nsresult SetPrintPreviewMode (PRBool previewMode);
 	nsresult PrintPreviewNumPages (int *numPages);
 	nsresult PrintPreviewNavigate(PRInt16 navType, PRInt32 pageNum);
 
@@ -104,9 +103,15 @@ public:
 
 	nsresult GetSHInfo (PRInt32 *count, PRInt32 *index);
 	nsresult GetSHTitleAtIndex (PRInt32 index, PRUnichar **title);
-	nsresult GetSHUrlAtIndex (PRInt32 index, nsCString &url);
+	nsresult GetSHUrlAtIndex (PRInt32 index, nsACString &url);
 	nsresult GoToHistoryIndex (PRInt16 index);
 
+	enum { RELOAD_NORMAL = 0 };
+	enum { RELOAD_FORCE = 1 };
+	enum { RELOAD_ENCODING_CHANGE = 2 };
+
+	nsresult Reload (PRUint32 flags);
+
 	nsresult ForceEncoding (const char *encoding);
 
 	nsresult GetEncodingInfo (EphyEncodingInfo **infoptr);
@@ -116,8 +121,8 @@ public:
 
 	nsresult GetDocument (nsIDOMDocument **aDOMDocument);
 	nsresult GetTargetDocument (nsIDOMDocument **aDOMDocument);
-	nsresult GetDocumentUrl (nsCString &url);
-	nsresult GetTargetDocumentUrl (nsCString &url);
+	nsresult GetDocumentUrl (nsACString &url);
+	nsresult GetTargetDocumentUrl (nsACString &url);
 
 	nsresult GetHasModifiedForms (PRBool *modified);
 
@@ -130,6 +135,7 @@ private:
 	nsCOMPtr<nsIDOMWindow> mDOMWindow;
 	EphyFaviconEventListener *mFaviconEventListener;
 	EphyPopupEventListener *mPopupEventListener;
+	PRBool mInitialized;
 
 	nsresult GetListener (void);
 	nsresult AttachListeners (void);
