@@ -1,4 +1,4 @@
-/*
+/*  vim:set ts=8 noet sw=8:
  *  Copyright (C) 2000-2003 Marco Pesenti Gritti
  *  Copyright (C) 2003 Christian Persch
  *
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-embed-single.cpp,v 1.68 2004/01/21 13:59:12 chpe Exp $
+ *  $Id: mozilla-embed-single.cpp,v 1.69.4.5 2004/07/25 11:06:43 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -76,6 +76,9 @@
 #include <nsIURI.h>
 #include <nsNetUtil.h>
 #include <nsIHttpAuthManager.h>
+#include <nsIPrintSettings.h>
+#include <nsIPrintSettingsService.h>
+#include <nsIPrintingPromptService.h>
 
 // FIXME: For setting the locale. hopefully gtkmozembed will do itself soon
 #include <nsIChromeRegistry.h>
@@ -99,11 +102,12 @@ struct MozillaEmbedSinglePrivate
 };
 
 static void mozilla_embed_single_class_init	(MozillaEmbedSingleClass *klass);
-static void ephy_embed_single_iface_init	(EphyEmbedSingleIFace *iface);
-static void ephy_cookie_manager_iface_init	(EphyCookieManagerIFace *iface);
-static void ephy_password_manager_iface_init	(EphyPasswordManagerIFace *iface);
-static void ephy_permission_manager_iface_init	(EphyPermissionManagerIFace *iface);
+static void ephy_embed_single_iface_init	(EphyEmbedSingleIface *iface);
+static void ephy_cookie_manager_iface_init	(EphyCookieManagerIface *iface);
+static void ephy_password_manager_iface_init	(EphyPasswordManagerIface *iface);
+static void ephy_permission_manager_iface_init	(EphyPermissionManagerIface *iface);
 static void mozilla_embed_single_init		(MozillaEmbedSingle *ges);
+static gboolean have_gnome_url_handler		(const gchar *protocol);
 
 static GObjectClass *parent_class = NULL;
 
@@ -220,6 +224,10 @@ mozilla_set_default_prefs (MozillaEmbedSingle *mes)
 	pref->SetCharPref ("general.useragent.vendor", "Epiphany");
 	pref->SetCharPref ("general.useragent.vendorSub", VERSION);
 
+	/* Open ftp uris with an external handler if one is setup */
+	pref->SetBoolPref("network.protocol-handler.external.ftp",
+			  have_gnome_url_handler ("ftp"));
+
 	return TRUE;
 }
 
@@ -359,20 +367,6 @@ have_gnome_url_handler (const gchar *protocol)
 	return rv;
 }
 
-static void
-mozilla_register_external_protocols (void)
-{
-	/* FIXME register only when needed */
-	if (have_gnome_url_handler ("ftp"))
-	{
-		mozilla_register_FtpProtocolHandler ();
-	}
-	else
-	{
-		mozilla_unregister_FtpProtocolHandler ();
-	}
-}
-
 static nsresult
 getUILang (nsAString& aUILang)
 {
@@ -428,11 +422,16 @@ mozilla_init_chrome (void)
 static void
 mozilla_init_observer (MozillaEmbedSingle *single)
 {
-	single->priv->mSingleObserver = new EphySingle ();
+	EphySingle *es;
 
-	if (single->priv->mSingleObserver)
+	es = new EphySingle ();
+	NS_ADDREF (single->priv->mSingleObserver = es);
+
+	nsresult rv;
+	rv = es->Init (EPHY_EMBED_SINGLE (single));
+	if (NS_FAILED (rv))
 	{
-		single->priv->mSingleObserver->Init (EPHY_EMBED_SINGLE (single));
+		g_warning ("Failed to initialised EphySingle!\n");
 	}
 }
 
@@ -467,8 +466,6 @@ init_services (MozillaEmbedSingle *single)
 
 	mozilla_register_components ();
 
-	mozilla_register_external_protocols ();
-
 	mozilla_init_observer (single);
 
 	return TRUE;
@@ -507,6 +504,19 @@ mozilla_embed_single_init (MozillaEmbedSingle *mes)
 	}
 }
 
+static void
+mozilla_embed_single_dispose (GObject *object)
+{
+	MozillaEmbedSingle *single = MOZILLA_EMBED_SINGLE (object);
+
+	if (single->priv->mSingleObserver)
+	{
+		single->priv->mSingleObserver->Detach ();
+		NS_RELEASE (single->priv->mSingleObserver);
+		single->priv->mSingleObserver = nsnull;
+	}		
+}
+
 static void
 mozilla_embed_single_finalize (GObject *object)
 {
@@ -568,7 +578,11 @@ impl_load_proxy_autoconf (EphyEmbedSingle *shell,
                 do_GetService ("@mozilla.org/network/protocol-proxy-service;1");
 	if (!pps) return;
 
+#if MOZILLA_SNAPSHOT >= 19
+	pps->ConfigureFromPAC (nsDependentCString (url));
+#else
 	pps->ConfigureFromPAC (url);
+#endif
 }
 
 static GList *
@@ -602,6 +616,24 @@ impl_get_font_list (EphyEmbedSingle *shell,
 	return g_list_reverse (l);
 }
 
+static void
+impl_print_setup (EphyEmbedSingle *single)
+{
+	nsCOMPtr<nsIPrintSettingsService> pss
+		(do_GetService ("@mozilla.org/gfx/printsettings-service;1"));
+	if (!pss) return;
+
+	nsCOMPtr<nsIPrintSettings> settings;
+	pss->GetGlobalPrintSettings (getter_AddRefs (settings));
+	if (!settings) return;
+
+	nsCOMPtr<nsIPrintingPromptService> prompt
+		(do_GetService ("@mozilla.org/embedcomp/printingprompt-service;1"));
+	if (!prompt) return;
+
+	prompt->ShowPageSetup (nsnull, settings, nsnull);
+}
+
 static GList *
 impl_list_cookies (EphyCookieManager *manager)
 {
@@ -871,23 +903,25 @@ mozilla_embed_single_class_init (MozillaEmbedSingleClass *klass)
 
 	parent_class = (GObjectClass *) g_type_class_peek_parent (klass);
 
+	object_class->dispose = mozilla_embed_single_dispose;
 	object_class->finalize = mozilla_embed_single_finalize;
 
 	g_type_class_add_private (object_class, sizeof (MozillaEmbedSinglePrivate));
 }
 
 static void
-ephy_embed_single_iface_init (EphyEmbedSingleIFace *iface)
+ephy_embed_single_iface_init (EphyEmbedSingleIface *iface)
 {
 	iface->clear_cache = impl_clear_cache;
 	iface->clear_auth_cache = impl_clear_auth_cache;
 	iface->set_offline_mode = impl_set_offline_mode;
 	iface->load_proxy_autoconf = impl_load_proxy_autoconf;
 	iface->get_font_list = impl_get_font_list;
+	iface->print_setup = impl_print_setup;
 }
 
 static void
-ephy_cookie_manager_iface_init (EphyCookieManagerIFace *iface)
+ephy_cookie_manager_iface_init (EphyCookieManagerIface *iface)
 {
 	iface->list = impl_list_cookies;
 	iface->remove = impl_remove_cookie;
@@ -895,7 +929,7 @@ ephy_cookie_manager_iface_init (EphyCookieManagerIFace *iface)
 }
 
 static void
-ephy_password_manager_iface_init (EphyPasswordManagerIFace *iface)
+ephy_password_manager_iface_init (EphyPasswordManagerIface *iface)
 {
 	iface->add = NULL; /* not implemented yet */
 	iface->remove = impl_remove_password;
@@ -903,7 +937,7 @@ ephy_password_manager_iface_init (EphyPasswordManagerIFace *iface)
 }
 
 static void
-ephy_permission_manager_iface_init (EphyPermissionManagerIFace *iface)
+ephy_permission_manager_iface_init (EphyPermissionManagerIface *iface)
 {
 	iface->add = impl_permission_manager_add;
 	iface->remove = impl_permission_manager_remove;
